==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicScatterAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColorScaleDescriptionMetadata } from "./ColorScaleDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicScatterAreaSeriesDescription } from "./GeographicScatterAreaSeriesDescription";
/**
 * @hidden
 */
export let GeographicScatterAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicScatterAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicScatterAreaSeriesDescriptionMetadata.a == null) {
                GeographicScatterAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicScatterAreaSeriesDescriptionMetadata.c(GeographicScatterAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicScatterAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicScatterAreaSeriesDescriptionMetadata.a);
            ColorScaleDescriptionMetadata.d(a);
            TriangulationStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
            a.item("ColorMemberPath", "String");
            a.item("ColorScale", "ExportedType:ColorScale");
            a.item("ActualColorScale", "ExportedType:ColorScale");
            a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
        }
        static d(a) {
            GeographicScatterAreaSeriesDescriptionMetadata.b(a);
            a.ad("GeographicScatterAreaSeries", () => new GeographicScatterAreaSeriesDescription());
            a.ac("GeographicScatterAreaSeries", GeographicScatterAreaSeriesDescriptionMetadata.a);
        }
    }
    GeographicScatterAreaSeriesDescriptionMetadata.$t = markType(GeographicScatterAreaSeriesDescriptionMetadata, 'GeographicScatterAreaSeriesDescriptionMetadata');
    GeographicScatterAreaSeriesDescriptionMetadata.a = null;
    return GeographicScatterAreaSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicScatterAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColorScaleDescriptionMetadata } from "./ColorScaleDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicScatterAreaSeriesDescription } from "./GeographicScatterAreaSeriesDescription";
/**
 * @hidden
 */
export let GeographicScatterAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicScatterAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicScatterAreaSeriesDescriptionMetadata.a == null) {
                GeographicScatterAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicScatterAreaSeriesDescriptionMetadata.c(GeographicScatterAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicScatterAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicScatterAreaSeriesDescriptionMetadata.a);
            ColorScaleDescriptionMetadata.d(a);
            TriangulationStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
            a.item("ColorMemberPath", "String");
            a.item("ColorScale", "ExportedType:ColorScale");
            a.item("ActualColorScale", "ExportedType:ColorScale");
            a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
        }
        static d(a) {
            GeographicScatterAreaSeriesDescriptionMetadata.b(a);
            a.ae("GeographicScatterAreaSeries", () => new GeographicScatterAreaSeriesDescription());
            a.ad("GeographicScatterAreaSeries", GeographicScatterAreaSeriesDescriptionMetadata.a);
        }
    }
    GeographicScatterAreaSeriesDescriptionMetadata.$t = markType(GeographicScatterAreaSeriesDescriptionMetadata, 'GeographicScatterAreaSeriesDescriptionMetadata');
    GeographicScatterAreaSeriesDescriptionMetadata.a = null;
    return GeographicScatterAreaSeriesDescriptionMetadata;
})();
